@@ -51,7 +51,7 @@ sub new {
                                     error_format => 'html',
                                     %p);
 
-    $self->{custom_out_method} = $p{out_method} ? 1 : 0;
+    $self->{has_custom_out_method} = $p{out_method} ? 1 : 0;
 
     $self->interp->compiler->add_allowed_globals('$r');
     
@@ -207,6 +207,8 @@ sub exec
         and (!$retval or $retval==200)) {
         $r->send_http_header();
     }
+
+    return $retval;
 }
 
 sub redirect {
